@@ -5,7 +5,11 @@ from django.urls import URLPattern, URLResolver
 
 
 def normalize_str_route(_url_pattern: URLPattern):
-    return re.sub(r'<([a-zA-Z]+):([a-zA-Z0-9-_]+)>', r"{\g<2>}", _url_pattern.pattern._route)
+    return \
+        re.sub(
+            r'<([a-zA-Z]+):([a-zA-Z0-9-_]+)>', r"{\g<2>}",
+            _url_pattern if isinstance(_url_pattern, str) else _url_pattern.pattern._route
+        )
 
 
 def detect_urlpatterns(resolver):
@@ -17,7 +21,7 @@ def detect_urlpatterns(resolver):
 def generate_route(resolver, pattern, url_pattern):
     if isinstance(resolver, URLResolver):
         return os.path.join(pattern._route, normalize_str_route(url_pattern))
-    return pattern._route
+    return normalize_str_route(pattern._route)
 
 
 def collect_routes(all_resolver):
