@@ -113,9 +113,10 @@ class Method(object):
                 "200": {
                     "description": "OK"
                 }
-            },
-            'tags': self.tags
+            }
         }
+        if self.tags:
+            base.update({'tags': self.tags})
 
         if self.description:
             base.update({
