@@ -16,7 +16,8 @@ class OpenApiFile(View):
         version = django_params.get("version")
 
         if getattr(settings, 'DEBUG'):
-            debug_host = f'http://{request.META["HTTP_HOST"]}'
+            schema = getattr(settings, 'OPENAPI_DJANGO').get('schema', 'http')
+            debug_host = f'{schema}://{request.META["HTTP_HOST"]}'
             if debug_host not in servers:
                 servers.append(debug_host)
 
